<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=no
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_effacer_statistiques' => 'Delete the statistics', # MODIF

	// I
	'info_forum_statistiques' => 'Statistiques des visites',
	'info_previsions' => 'prévisions :',
	'item_gerer_statistiques' => ' Gérer les statistiques',

	// R
	'resume' => 'Resume', # MODIF
];
